@@ -1,4 +1,4 @@
-/* $Id: functions.h 3940 2008-02-10 22:48:45Z nebulon $
+/* $Id: functions.h 5178 2008-07-30 22:42:44Z mmassonnet $
  *
  * Copyright (c) 2006 Johannes Zellner, <webmaster@nebulon.de>
  *
@@ -35,14 +35,7 @@
 
 #include "types.h"
 #include "interface.h"
-
-#ifdef __LINUX__
-#include "xfce-taskmanager-linux.h"
-#endif
-
-#define PROC_DIR_1 "/compat/linux/proc"
-#define PROC_DIR_2 "/emul/linux/proc"
-#define PROC_DIR_3 "/proc"
+#include "taskmanager.h"
 
 gboolean refresh_task_list(void);
 gdouble get_cpu_usage(system_status *sys_stat);
