@@ -1,4 +1,4 @@
-/* $Id: interface.c 4824 2008-05-18 17:37:39Z mmassonnet $
+/* $Id: interface.c 5416 2008-09-15 21:17:14Z mmassonnet $
  *
  * Copyright (c) 2006  Johannes Zellner <webmaster@nebulon.de>
  *               2008  Mike Massonnet <mmassonnet@xfce.org>
@@ -20,17 +20,10 @@
 
 #include "interface.h"
 
-#define GLADE_HOOKUP_OBJECT(component,widget,name) \
-  g_object_set_data_full (G_OBJECT (component), name, \
-    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
-
-#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
-  g_object_set_data (G_OBJECT (component), name, widget)
-
 GtkWidget* create_main_window (void)
 {
 	GtkWidget *window;
-	GtkWidget *vbox1;
+	GtkWidget *vbox1, *vbox2;
 	GtkWidget *bbox1;
 	GtkWidget *scrolledwindow1;
 	GtkWidget *button_preferences;
@@ -39,22 +32,28 @@ GtkWidget* create_main_window (void)
 
 	GtkWidget *system_info_box;
 
+#if !GTK_CHECK_VERSION (2, 12, 0)
 	tooltips = gtk_tooltips_new();
 	gtk_tooltips_enable(tooltips);
+#endif
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (window), _("Xfce4 Taskmanager"));
-	gtk_window_set_icon_name (GTK_WINDOW (window), "xfce-system");
+	gtk_window_set_icon_name (GTK_WINDOW (window), "utilities-system-monitor");
 	gtk_window_set_default_size (GTK_WINDOW (window), win_width, win_height);
 
-	vbox1 = gtk_vbox_new (FALSE, 10);
+	vbox1 = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (vbox1);
 	gtk_container_add (GTK_CONTAINER (window), vbox1);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 10);
 
-	system_info_box = gtk_hbox_new (FALSE, 10);
+	vbox2 = gtk_vbox_new (FALSE, BORDER);
+	gtk_widget_show (vbox2);
+	gtk_container_add (GTK_CONTAINER (vbox1), vbox2);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox2), BORDER);
+
+	system_info_box = gtk_hbox_new (FALSE, BORDER/2);
 	gtk_widget_show (system_info_box);
-	gtk_box_pack_start (GTK_BOX (vbox1), system_info_box, FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), system_info_box, FALSE, TRUE, 0);
 
 	cpu_usage_progress_bar_box = gtk_event_box_new ();
 	cpu_usage_progress_bar = gtk_progress_bar_new ();
@@ -75,11 +74,11 @@ GtkWidget* create_main_window (void)
 	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
 	gtk_widget_show (scrolledwindow1);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start (GTK_BOX (vbox1), scrolledwindow1, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), scrolledwindow1, TRUE, TRUE, 0);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_SHADOW_IN);
 
 	treeview = gtk_tree_view_new ();
-    gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (treeview), FALSE);
+	gtk_tree_view_set_show_expanders (GTK_TREE_VIEW (treeview), FALSE);
 	gtk_widget_show (treeview);
 	gtk_container_add (GTK_CONTAINER (scrolledwindow1), treeview);
 
@@ -92,7 +91,7 @@ GtkWidget* create_main_window (void)
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(list_store), sort_column, sort_type);
 
 	bbox1 = gtk_hbutton_box_new();
-	gtk_box_pack_start(GTK_BOX(vbox1), bbox1, FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox2), bbox1, FALSE, TRUE, 0);
 	gtk_widget_show (bbox1);
 
 	button_preferences = gtk_button_new_from_stock ("gtk-preferences");
@@ -109,6 +108,12 @@ GtkWidget* create_main_window (void)
 	gtk_widget_show (button_quit);
 	gtk_box_pack_start (GTK_BOX (bbox1), button_quit, FALSE, FALSE, 0);
 
+#if 0
+	statusbar = gtk_statusbar_new ();
+	gtk_widget_show (statusbar);
+	gtk_box_pack_start (GTK_BOX (vbox1), statusbar, FALSE, FALSE, 0);
+#endif
+
 	g_signal_connect_swapped (treeview, "button-press-event", G_CALLBACK(on_treeview1_button_press_event), NULL);
 	g_signal_connect (button_preferences, "clicked",  G_CALLBACK (on_preferences),  NULL);
 	g_signal_connect (button_information, "clicked",  G_CALLBACK (on_information),  NULL);
@@ -372,30 +377,33 @@ void show_about_dialog(void)
 {
 	GtkWidget *about_dialog;
 	const gchar *authors[] = {
-	  _("Original Author:"),
 	  "Johannes Zellner <webmaster@nebulon.de>",
+      "",
 	  _("Contributors:"),
 	  "Mike Massonnet <mmassonnet@xfce.org>",
 	  NULL };
 
 	about_dialog = gtk_about_dialog_new();
-	gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(about_dialog),
-		PACKAGE_NAME);
-	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about_dialog),
+	gtk_about_dialog_set_version(
+		GTK_ABOUT_DIALOG(about_dialog),
 		PACKAGE_VERSION);
-	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about_dialog),
+	gtk_about_dialog_set_comments(
+		GTK_ABOUT_DIALOG(about_dialog),
 		_("Xfce4-Taskmanager is an easy to use taskmanager"));
-	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(about_dialog),
+	gtk_about_dialog_set_website(
+		GTK_ABOUT_DIALOG(about_dialog),
 		"http://goodies.xfce.org/projects/applications/xfce4-taskmanager");
-	gtk_about_dialog_set_logo_icon_name(GTK_ABOUT_DIALOG(about_dialog),
-		"xfce-system");
-	gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(about_dialog),
+	gtk_about_dialog_set_authors(
+		GTK_ABOUT_DIALOG(about_dialog),
 		authors);
-	gtk_about_dialog_set_translator_credits(GTK_ABOUT_DIALOG(about_dialog),
+	gtk_about_dialog_set_translator_credits(
+		GTK_ABOUT_DIALOG(about_dialog),
 		_("translator-credits"));
-	gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(about_dialog),
+	gtk_about_dialog_set_license(
+		GTK_ABOUT_DIALOG(about_dialog),
 		xfce_get_license_text(XFCE_LICENSE_TEXT_GPL));
-	gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(about_dialog),
+	gtk_about_dialog_set_copyright(
+		GTK_ABOUT_DIALOG(about_dialog),
 		"Copyright \302\251 2005-2008 Johannes Zellner");
 
 	gtk_window_set_icon_name(GTK_WINDOW(about_dialog), GTK_STOCK_ABOUT);
@@ -419,19 +427,32 @@ void change_list_store_view(void)
 
 void fill_list_item(gint i, GtkTreeIter *iter)
 {
+	struct task *task;
+	gchar *pid;
+	gchar *ppid;
+	gchar *state;
+	gchar *vsize;
+	gchar *rss;
+	gchar *name;
+	gchar *uname;
+	gchar *time;
+	gchar *prio;
+
 	if(iter != NULL)
 	{
-		struct task *task = &g_array_index(task_array, struct task, i);
+		task = &g_array_index(task_array, struct task, i);
 
-		gchar *pid = g_strdup_printf("%i", task->pid);
-		gchar *ppid = g_strdup_printf("%i", task->ppid);
-		gchar *state = g_strdup_printf("%s", task->state);
-		gchar *vsize = g_strdup_printf("%i MB", task->vsize/1024/1024);
-		gchar *rss = g_strdup_printf("%i MB", task->rss/1024/1024);
-		gchar *name = g_strdup_printf("%s", task->name);
-		gchar *uname = g_strdup_printf("%s", task->uname);
-		gchar *time = g_strdup_printf("%0d%%", (guint)task->time_percentage);
-		gchar *prio = g_strdup_printf("%i", task->prio);	/* my change */
+		pid = g_strdup_printf("%i", task->pid);
+		ppid = g_strdup_printf("%i", task->ppid);
+		state = g_strdup_printf("%s", task->state);
+		vsize = g_strdup_printf((task->vsize/1024/1024 > 0) ? "%.0f MB" : "%.2f MB",
+					(gdouble)(task->vsize)/1024/1024);
+		rss = g_strdup_printf((task->rss/1024/1024 > 0) ? "%.0f MB" : "%.2f MB",
+					(gdouble)(task->rss)/1024/1024);
+		name = g_strdup_printf("%s", task->name);
+		uname = g_strdup_printf("%s", task->uname);
+		time = g_strdup_printf("%0d%%", (guint)task->time_percentage);
+		prio = g_strdup_printf("%i", task->prio);	/* my change */
 
 		gtk_tree_store_set(GTK_TREE_STORE(list_store), iter, COLUMN_NAME, name, -1);
 		gtk_tree_store_set(GTK_TREE_STORE(list_store), iter, COLUMN_PID, pid, -1);
@@ -514,19 +535,19 @@ gint compare_int_list_item(GtkTreeModel *model, GtkTreeIter *iter1, GtkTreeIter
 	gchar *s1 = "";
 	gchar *s2 = "";
 
+	gdouble i1 = 0;
+	gdouble i2 = 0;
+
 	gint ret = 0;
 
 	gtk_tree_model_get(model, iter1, column, &s1, -1);
 	gtk_tree_model_get(model, iter2, column, &s2, -1);
 
-	gint i1 = 0;
-	gint i2 = 0;
-
 	if(s1 != NULL)
-		i1 = atoi(s1);
+		i1 = 100 * g_strtod(s1, NULL);
 
 	if(s2 != NULL)
-		i2 = atoi(s2);
+		i2 = 100 * g_strtod(s2, NULL);
 
 	ret = i2 - i1;
 
@@ -549,7 +570,7 @@ gint compare_string_list_item(GtkTreeModel *model, GtkTreeIter *iter1, GtkTreeIt
 	gtk_tree_model_get(model, iter2, GPOINTER_TO_INT(column), &s2, -1);
 
 	if(s1 != NULL && s2 != NULL)
-		ret = strcmp(s2, s1);
+		ret = strcasecmp(s2, s1);
 	else
 		ret = 0;
 
