@@ -1,4 +1,4 @@
-/* $Id: interface.h 4806 2008-05-16 07:05:20Z mmassonnet $
+/* $Id: interface.h 5416 2008-09-15 21:17:14Z mmassonnet $
  *
  * Copyright (c) 2006 Johannes Zellner, <webmaster@nebulon.de>
  *
@@ -40,12 +40,16 @@
 #include "callbacks.h"
 #include "types.h"
 
+#define BORDER 8
+
 GtkTreeStore *list_store;
 GtkTreeSelection *selection;
 GtkWidget *treeview;
 GtkWidget *mainmenu;
 GtkWidget *infomenu;
+#if !GTK_CHECK_VERSION (2, 12, 0)
 GtkTooltips *tooltips;
+#endif
 GtkWidget *taskpopup;
 GtkWidget *priopopup;
 GtkWidget *cpu_usage_progress_bar;
